@@ -1,4 +1,4 @@
-from attr import attrs, attrib
+from attr import attrib, attrs
 
 
 # TODO: Add model to python-commons
