@@ -1,11 +1,11 @@
-from enum import Enum
 import traceback
+from enum import Enum
 
-from testit_python_commons.services.utils import Utils
 from testit_python_commons.models.outcome_type import OutcomeType
+from testit_python_commons.services.utils import Utils
 
-from .tags_parser import parse_tags
 from .models.tags import TagType
+from .tags_parser import parse_tags
 
 STATUS = {
     'passed': OutcomeType.PASSED,
@@ -80,7 +80,7 @@ def get_scenario_name(scenario):
 
 
 def get_scenario_external_id(scenario):
-    return Utils.getHash(scenario.feature.filename + scenario.name)
+    return Utils.get_hash(scenario.feature.filename + scenario.name)
 
 
 def get_scenario_namespace(scenario):
